*GENERAL INFO
	* Paper: Who is Targeted in Corruption? Disentangling the Effects of Wealth and Power on Exposure to Bribery
	* Created by: Amanda Lea Robinson
	* Created on: December 29, 2017
* DO FILE INFO
	* This .do file runs all analyses presented in the manuscript and appendix.
	* Requires RS_QJPS_Data.dta file.

	
****************************************************************

set more off

use "RS_QJPS_Data.dta", clear

*defining control variables
global controls_stopped rbtype number_officials hour 
global cov_sel ses rbtype number_officials hour 
global cov rbtype number_officials 

*****************************
* Analyses in the Main Text *
*****************************

    * DV=stopped or not
	tab ses stopped, exact
    eststo m1: reg stopped i.ses $controls_stopped i.ra

    * DV=bribe paid, no selection
    tab power, summ(bribepaid)
	tab ses bribepaid if citationpaid~=1, exact
	tab power bribepaid if citationpaid~=1, exact
    eststo m2: reg bribepaid i.ses i.power coreg $cov i.ra  if citationpaid~=1
	eststo m3: reg bribepaid i.ses##i.power coreg $cov i.ra  if citationpaid~=1 
    margins, by(ses power)

    * DV=bribe paid, selection model 
    eststo m4: heckman bribepaid i.ses i.power coreg $cov  if citationpaid~=1, select(stopped=$cov_sel ) 
	eststo m5: heckman bribepaid i.ses##i.power coreg $cov   if citationpaid~=1, select(stopped=$cov_sel ) 

    * DV=bribe amount
    tab power, summ(bribe_amount)

    * Other Statistics Cited in Text
    tab ra
    tab rbtype
    tab power
    tab ses
    tab power ses
        egen racount=count(ra), by(ra)
        egen ratag=tag(ra)
    summ racount if ratag==1
        drop racount ratag
    tab number_officials
    summ bribe_amount if bribe_amount>0 
    summ bribe_amount if stopped==1 

****************************
* Analyses in the Appendix *
****************************

*summary statistics
global summary ses power coreg stopped bribepaid bribe_amount citationpaid citation_amount total $controls_stopped
estpost su $summary
est store summ_RT


*balance tests
foreach t in ses power coreg {
estpost ttest $controls_stopped , by(`t')
eststo bal_`t'_rt
}


* Analyses of Bribe Amount

	* DV= Bribe Amount, no selection
    eststo a1: reg bribe_amount i.ses i.power coreg $cov i.ra  if citationpaid~=1
	eststo a2: reg bribe_amount i.ses##i.power coreg $cov i.ra  if citationpaid~=1
    margins, by(ses power)

	* DV= Bribe Amount, selection model
	eststo a3: heckman bribe_amount i.ses i.power coreg $cov  if citationpaid~=1, select(stopped=$cov_sel ) 
	eststo a4: heckman bribe_amount ses##power coreg $cov  if citationpaid~=1, select(stopped=$cov_sel ) 

	
* Conditional logit instead of linear probabily model
	
	* DV=stopped or not
	eststo p1: clogit stopped i.ses $controls_stopped, group(ra)

	* DV=bribe paid, no selection
    eststo p2: clogit bribepaid i.ses i.power coreg $cov if citationpaid~=1, group(ra)
	eststo p3: clogit bribepaid i.ses##i.power coreg $cov  if citationpaid~=1, group(ra)

	* DV=bribe paid, selection model 
    eststo p4: heckprobit bribepaid i.ses i.power coreg $cov  if citationpaid~=1, select(stopped=$cov_sel ) 
	eststo p5: heckprobit bribepaid i.ses##i.power coreg $cov   if citationpaid~=1, select(stopped=$cov_sel ) 


* Multinomimal Logit 

	eststo mlrt: mlogit outcome ses power $cov , base(2)
	
	
* Coethnicity

	tab coreg bribepaid, exact
	ranksum bribe_amount, by(coreg)
    tab coreg, sum(bribe_amount)
	
****************
***  FIGURES ***
****************

hist bribe_amount, percent	///
	scheme(s2mono) graphregion(fcolor(white))  ///
	ytitle ("Percent of Police Interactions", size(small))
	
hist bribe_amount, percent by(treatment) ///
	scheme(s2mono) graphregion(fcolor(white))  ///
	ytitle ("Percent of Police Interactions", size(small))

*statistics for outcomes figure
tab stopped
tab citationpaid if stopped==1
tab bribepaid if citationpaid==0
sum bribe_amount if bribepaid==1



*********************
* Pre-Analysis Plan *
*********************

* pre-treatment covariates	
global cov rbtype number_officials superior_official	

* DV= Stopped
***************
eststo stopped: reg stopped ses rbtype number_officials i.ra

	*H1: High SES will reduce the likelihood of being stopped.
	ttest stopped, by(ses) // one-sided
	est rest stopped
	
	*H2: Political connections will reduce the likelihood of being stopped.
	ttest stopped, by(power) // one-sided 
	reg stopped ses power rbtype number_officials i.ra
	
	
*DV= Paying Bribe 
***************

	*H3: Ethnic match will decrease the likelihood of paying a bribe.
	*H3a: weak coethnicity
	ttest bribepaid, by(coreg)
	eststo bribepaid: reg bribepaid ses power coreg i.ra $cov
	*H3b: strong coethnicity
	ttest bribepaid, by(coeth)
	eststo bribepaid2: reg bribepaid ses power coeth i.ra $cov
	
*DV= Paying Citation
***************
	
	*H4 Ethnic match will decrease the likelihood of paying the full fine.
	*H4a: weak coethnicity
	ttest citationpaid, by(coreg)
	eststo citationpaid: reg citationpaid ses power coreg i.ra $cov
	*H4b: strong coethnicity
	ttest citationpaid, by(coeth)
	eststo citationpaid2: reg citationpaid ses power coeth i.ra $cov
	
	
	*H5: The impact of ethnic match on the likelihood of paying the full fine /// 
	     *will be larger, in absolute value, than the effect of ethnic match on /// 
		 *the likelihood of paying a bribe.
    preserve
    keep uid bribepaid citationpaid coeth coreg ses power ra $cov
    rename (bribepaid citationpaid) (outcome1 outcome2)
    reshape long outcome, i(uid) j(type)
    recode type (2=0)
    lab def type 1 "bribe" 0 "citation"
    lab val type type

    diff outcome, p(type) t(coreg)
    diff outcome, p(type) t(coeth)

    reg outcome i.coreg##i.type ses power i.ra $cov
    reg outcome i.coeth##i.type ses power i.ra $cov
    restore


	*H6: Political connections will increase the likelihood of paying nothing and being /// 
		 *released with a warning.
	ttest paid, by(power)	 
	eststo paid: reg paid ses power coreg i.ra $cov
		 
	*H7: Political connections will increase the likelihood of paying the full fine.
	ttest citationpaid, by(power)
	est restore citationpaid
	
	*H8: Political connections will decrease the likelihood of being asked to pay a bribe.
	ttest bribepaid, by(power)
	est restore bribepaid

	*H9: High SES will decrease the likelihood of of paying nothing and being released ///
		 *with a warning.
	ttest paid, by(ses)	 
	est restore paid
		 
	*H10: High SES will increase the likelihood of paying the full fine.
	ttest citationpaid, by(ses)
	est restore citationpaid
	
	
	*H11: High SES will increase the likelihood of being asked to pay a bribe, /// 
	      *but only in the absence of political connections.	
	ttest bribepaid, by(ses)
	bys power: ttest bribepaid, by(ses)
	bys power: reg bribepaid ses coreg i.ra $cov 

	
	
*DV= Amount of Bribe 
***************

*areg bribe_amount ses power coeth $amount_cov, abs(ra)
eststo bribe_amount: reg bribe_amount ses power coreg $cov i.ra
	
	*H12: Ethnic match will decrease the amount of the bribe paid.
	ttest bribe_amount, by(coreg)
	est restore bribe_amount
	ttest bribe_amount, by(coeth)
	reg bribe_amount ses power coeth $cov i.ra
	
	*H13: Political connections will decrease the amount of the bribe paid. 
	ttest bribe_amount, by(power)
	est restore bribe_amount
	
	
	*H14: High SES will increase the amount of the bribe paid.
	ttest bribe_amount, by(ses)
	est restore bribe_amount
	

	
